# OpenLibrary

## search

Searches of the OpenLibrary are not (yet) supported.

## prep

OpenLibrary linking

Note: This document is currently under development. It will contain the following elements.

- description
- example

## Links

- [OpenLibrary](https://openlibrary.org/)
